function [] = runme(force_overwrite)
  % By default we do not overwrite results
  if (nargin < 1)
    force_overwrite = false;
  end

  % Get list of all filenames in input directory
  filenames = dir('../input');  

  % Process all filenames in input directory
  for i = 1:size(filenames)
    [~, basename, ext] = fileparts(filenames(i).name); 

    % Iterate all .jpg files
    if (~filenames(i).isdir && strcmpi(ext, '.jpg'))
      % Determine input, output, and overlay filenames
      input_filename = ['../input/', basename, '.jpg'];
      output_filename = ['../output/', basename, '.jpg'];
      overlay_filename = ['../overlay/', basename, '.jpg'];

      % Create output and overlay images.
      % We create both if at least one does not already exist or if 'force_rewrite'
      % equals true.
      if (force_overwrite || ...
          ~exist(output_filename, 'file') || ~exist(overlay_filename, 'file')) 
        % Read input image
        input_image = im2double(imread(input_filename));
        
        % Create and save output image
        disp(['[+] Creating ' output_filename]);
        output_image = detecteyes(input_image);
        imwrite(output_image, output_filename);
        
        % Create and save overlay image
        disp(['[+] Creating ' overlay_filename]);
        overlay_image = createoverlay(input_image, output_image);
        imwrite(overlay_image, overlay_filename);
      else
        disp(['[-] Skipping ' output_filename]);
        disp(['[-] Skipping ' overlay_filename]);
      end
    end
  end
end
  

function [overlay_image] = createoverlay(image1, image2)
    if (size(image1, 3) == 1)
        image1 = gray2rgb(image1);
    end
    if (size(image2, 3) == 1)
        image2 = gray2red(image2);
    end
    overlay_image = (image1 + 4*image2) / 5;
end


function [color_image] = gray2rgb(image)
    color_image = repmat(image, [1 1 3]);
end


function [color_image] = gray2red(image)
    color_image = padarray(image, [0 0 2], 0, 'post');
end


